==> aliyun-java-sdk-vpc-3.1.12-sources.jar: com/aliyuncs/vpc/model/v20160428/ModifyVSwitchAttributeRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vpc.model.v20160428;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.vpc.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class ModifyVSwitchAttributeRequest extends RpcAcsRequest<ModifyVSwitchAttributeResponse> {
	   

	private Long resourceOwnerId;

	private Boolean enableIPv6;

	private String description;

	private String resourceOwnerAccount;

	private String ownerAccount;

	private Long ownerId;

	private Integer ipv6CidrBlock;

	private String vSwitchId;

	private String vSwitchName;
	public ModifyVSwitchAttributeRequest() {
		super("Vpc", "2016-04-28", "ModifyVSwitchAttribute", "vpc");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public Long getResourceOwnerId() {
		return this.resourceOwnerId;
	}

	public void setResourceOwnerId(Long resourceOwnerId) {
		this.resourceOwnerId = resourceOwnerId;
		if(resourceOwnerId != null){
			putQueryParameter("ResourceOwnerId", resourceOwnerId.toString());
		}
	}

	public Boolean getEnableIPv6() {
		return this.enableIPv6;
	}

	public void setEnableIPv6(Boolean enableIPv6) {
		this.enableIPv6 = enableIPv6;
		if(enableIPv6 != null){
			putQueryParameter("EnableIPv6", enableIPv6.toString());
		}
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
		if(description != null){
			putQueryParameter("Description", description);
		}
	}

	public String getResourceOwnerAccount() {
		return this.resourceOwnerAccount;
	}

	public void setResourceOwnerAccount(String resourceOwnerAccount) {
		this.resourceOwnerAccount = resourceOwnerAccount;
		if(resourceOwnerAccount != null){
			putQueryParameter("ResourceOwnerAccount", resourceOwnerAccount);
		}
	}

	public String getOwnerAccount() {
		return this.ownerAccount;
	}

	public void setOwnerAccount(String ownerAccount) {
		this.ownerAccount = ownerAccount;
		if(ownerAccount != null){
			putQueryParameter("OwnerAccount", ownerAccount);
		}
	}

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		if(ownerId != null){
			putQueryParameter("OwnerId", ownerId.toString());
		}
	}

	public Integer getIpv6CidrBlock() {
		return this.ipv6CidrBlock;
	}

	public void setIpv6CidrBlock(Integer ipv6CidrBlock) {
		this.ipv6CidrBlock = ipv6CidrBlock;
		if(ipv6CidrBlock != null){
			putQueryParameter("Ipv6CidrBlock", ipv6CidrBlock.toString());
		}
	}

	public String getVSwitchId() {
		return this.vSwitchId;
	}

	public void setVSwitchId(String vSwitchId) {
		this.vSwitchId = vSwitchId;
		if(vSwitchId != null){
			putQueryParameter("VSwitchId", vSwitchId);
		}
	}

	public String getVSwitchName() {
		return this.vSwitchName;
	}

	public void setVSwitchName(String vSwitchName) {
		this.vSwitchName = vSwitchName;
		if(vSwitchName != null){
			putQueryParameter("VSwitchName", vSwitchName);
		}
	}

	@Override
	public Class<ModifyVSwitchAttributeResponse> getResponseClass() {
		return ModifyVSwitchAttributeResponse.class;
	}

}

==> aliyun-java-sdk-vpc-3.2.24-sources.jar: com/aliyuncs/vpc/model/v20160428/ModifyVSwitchAttributeRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vpc.model.v20160428;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.vpc.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class ModifyVSwitchAttributeRequest extends RpcAcsRequest<ModifyVSwitchAttributeResponse> {
	   

	private Long resourceOwnerId;

	private Boolean enableIPv6;

	private String description;

	private String resourceOwnerAccount;

	private String ownerAccount;

	private Long ownerId;

	private Integer ipv6CidrBlock;

	private String vSwitchId;

	private String vpcIpv6CidrBlock;

	private String vSwitchName;
	public ModifyVSwitchAttributeRequest() {
		super("Vpc", "2016-04-28", "ModifyVSwitchAttribute", "vpc");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public Long getResourceOwnerId() {
		return this.resourceOwnerId;
	}

	public void setResourceOwnerId(Long resourceOwnerId) {
		this.resourceOwnerId = resourceOwnerId;
		if(resourceOwnerId != null){
			putQueryParameter("ResourceOwnerId", resourceOwnerId.toString());
		}
	}

	public Boolean getEnableIPv6() {
		return this.enableIPv6;
	}

	public void setEnableIPv6(Boolean enableIPv6) {
		this.enableIPv6 = enableIPv6;
		if(enableIPv6 != null){
			putQueryParameter("EnableIPv6", enableIPv6.toString());
		}
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
		if(description != null){
			putQueryParameter("Description", description);
		}
	}

	public String getResourceOwnerAccount() {
		return this.resourceOwnerAccount;
	}

	public void setResourceOwnerAccount(String resourceOwnerAccount) {
		this.resourceOwnerAccount = resourceOwnerAccount;
		if(resourceOwnerAccount != null){
			putQueryParameter("ResourceOwnerAccount", resourceOwnerAccount);
		}
	}

	public String getOwnerAccount() {
		return this.ownerAccount;
	}

	public void setOwnerAccount(String ownerAccount) {
		this.ownerAccount = ownerAccount;
		if(ownerAccount != null){
			putQueryParameter("OwnerAccount", ownerAccount);
		}
	}

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		if(ownerId != null){
			putQueryParameter("OwnerId", ownerId.toString());
		}
	}

	public Integer getIpv6CidrBlock() {
		return this.ipv6CidrBlock;
	}

	public void setIpv6CidrBlock(Integer ipv6CidrBlock) {
		this.ipv6CidrBlock = ipv6CidrBlock;
		if(ipv6CidrBlock != null){
			putQueryParameter("Ipv6CidrBlock", ipv6CidrBlock.toString());
		}
	}

	public String getVSwitchId() {
		return this.vSwitchId;
	}

	public void setVSwitchId(String vSwitchId) {
		this.vSwitchId = vSwitchId;
		if(vSwitchId != null){
			putQueryParameter("VSwitchId", vSwitchId);
		}
	}

	public String getVpcIpv6CidrBlock() {
		return this.vpcIpv6CidrBlock;
	}

	public void setVpcIpv6CidrBlock(String vpcIpv6CidrBlock) {
		this.vpcIpv6CidrBlock = vpcIpv6CidrBlock;
		if(vpcIpv6CidrBlock != null){
			putQueryParameter("VpcIpv6CidrBlock", vpcIpv6CidrBlock);
		}
	}

	public String getVSwitchName() {
		return this.vSwitchName;
	}

	public void setVSwitchName(String vSwitchName) {
		this.vSwitchName = vSwitchName;
		if(vSwitchName != null){
			putQueryParameter("VSwitchName", vSwitchName);
		}
	}

	@Override
	public Class<ModifyVSwitchAttributeResponse> getResponseClass() {
		return ModifyVSwitchAttributeResponse.class;
	}

}
